from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Int, File, Float, String

Cmscan_V0_1_0 = CommandToolBuilder(tool="cmscan", base_command=["cmscan"], inputs=[ToolInput(tag="in_configure_cm_glocal", input_type=Boolean(optional=True), prefix="-g", doc=InputDocumentation(doc=": configure CM for glocal alignment [default: local]")), ToolInput(tag="in_set_search_size", input_type=Int(optional=True), prefix="-Z", doc=InputDocumentation(doc=": set search space size in *Mb* to <x> for E-value calculations  (x>0)")), ToolInput(tag="in_devhelp", input_type=Boolean(optional=True), prefix="--devhelp", doc=InputDocumentation(doc=": show list of otherwise hidden developer/expert options")), ToolInput(tag="in_direct_output_file", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc=": direct output to file <f>, not stdout")), ToolInput(tag="in_tbl_out", input_type=File(optional=True), prefix="--tblout", doc=InputDocumentation(doc=": save parseable table of hits to file <s>")), ToolInput(tag="in_fmt", input_type=Int(optional=True), prefix="--fmt", doc=InputDocumentation(doc=": set hit table format to <n>  (1<=n<=2)")), ToolInput(tag="in_acc", input_type=Boolean(optional=True), prefix="--acc", doc=InputDocumentation(doc=": prefer accessions over names in output")), ToolInput(tag="in_no_ali", input_type=Boolean(optional=True), prefix="--noali", doc=InputDocumentation(doc=": don't output alignments, so output is smaller")), ToolInput(tag="in_no_text_w", input_type=Boolean(optional=True), prefix="--notextw", doc=InputDocumentation(doc=": unlimit ASCII text output line width")), ToolInput(tag="in_text_w", input_type=Int(optional=True), prefix="--textw", doc=InputDocumentation(doc=": set max width of ASCII text output lines  [120]  (n>=120)")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc=": report extra information; mainly useful for debugging")), ToolInput(tag="in_report_sequences_threshold", input_type=Float(optional=True), prefix="-E", doc=InputDocumentation(doc=": report sequences <= this E-value threshold in output  [10.0]  (x>0)")), ToolInput(tag="in_report_sequences_score", input_type=String(optional=True), prefix="-T", doc=InputDocumentation(doc=": report sequences >= this score threshold in output")), ToolInput(tag="in_ince", input_type=Float(optional=True), prefix="--incE", doc=InputDocumentation(doc=": consider sequences <= this E-value threshold as significant  [0.01]")), ToolInput(tag="in_in_ct", input_type=String(optional=True), prefix="--incT", doc=InputDocumentation(doc=": consider sequences >= this score threshold as significant")), ToolInput(tag="in_cut_ga", input_type=Boolean(optional=True), prefix="--cut_ga", doc=InputDocumentation(doc=": use CM's GA gathering cutoffs as reporting thresholds")), ToolInput(tag="in_cut_nc", input_type=Boolean(optional=True), prefix="--cut_nc", doc=InputDocumentation(doc=": use CM's NC noise cutoffs as reporting thresholds")), ToolInput(tag="in_cut_tc", input_type=Boolean(optional=True), prefix="--cut_tc", doc=InputDocumentation(doc=": use CM's TC trusted cutoffs as reporting thresholds")), ToolInput(tag="in_max", input_type=Boolean(optional=True), prefix="--max", doc=InputDocumentation(doc=": turn all heuristic filters off (slow)")), ToolInput(tag="in_no_hmm", input_type=Boolean(optional=True), prefix="--nohmm", doc=InputDocumentation(doc=": skip all HMM filter stages, use only CM (slow)")), ToolInput(tag="in_mid", input_type=Boolean(optional=True), prefix="--mid", doc=InputDocumentation(doc=": skip first two HMM filter stages (SSV & Vit)")), ToolInput(tag="in_default", input_type=Boolean(optional=True), prefix="--default", doc=InputDocumentation(doc=": default: run search space size-dependent pipeline  [default]")), ToolInput(tag="in_rf_am", input_type=Boolean(optional=True), prefix="--rfam", doc=InputDocumentation(doc=": set heuristic filters at Rfam-level (fast)")), ToolInput(tag="in_hmm_only", input_type=Boolean(optional=True), prefix="--hmmonly", doc=InputDocumentation(doc=": use HMM only, don't use a CM at all")), ToolInput(tag="in_fz", input_type=Int(optional=True), prefix="--FZ", doc=InputDocumentation(doc=": set filters to defaults used for a search space of size <x> Mb")), ToolInput(tag="in_fmid", input_type=Float(optional=True), prefix="--Fmid", doc=InputDocumentation(doc=": with --mid, set P-value threshold for HMM stages to <x>  [0.02]")), ToolInput(tag="in_not_run_c", input_type=Boolean(optional=True), prefix="--notrunc", doc=InputDocumentation(doc=": do not allow truncated hits at sequence termini")), ToolInput(tag="in_any_trunc", input_type=Boolean(optional=True), prefix="--anytrunc", doc=InputDocumentation(doc=": allow full and truncated hits anywhere within sequences")), ToolInput(tag="in_no_hmm_only", input_type=Boolean(optional=True), prefix="--nohmmonly", doc=InputDocumentation(doc=": never run HMM-only mode, not even for models with 0 basepairs")), ToolInput(tag="in_no_null_three", input_type=Boolean(optional=True), prefix="--nonull3", doc=InputDocumentation(doc=": turn off the NULL3 post hoc additional null model")), ToolInput(tag="in_mx_size", input_type=Int(optional=True), prefix="--mxsize", doc=InputDocumentation(doc=": set max allowed alnment mx size to <x> Mb [df: autodetermined]")), ToolInput(tag="in_smx_size", input_type=Int(optional=True), prefix="--smxsize", doc=InputDocumentation(doc=": set max allowed size of search DP matrices to <x> Mb  [128.]")), ToolInput(tag="in_cy_k", input_type=Boolean(optional=True), prefix="--cyk", doc=InputDocumentation(doc=": use scanning CM CYK algorithm, not Inside in final stage")), ToolInput(tag="in_acy_k", input_type=Boolean(optional=True), prefix="--acyk", doc=InputDocumentation(doc=": align hits with CYK, not optimal accuracy")), ToolInput(tag="in_wcx", input_type=Int(optional=True), prefix="--wcx", doc=InputDocumentation(doc=": set W (expected max hit len) as <x> * cm->clen (model len)")), ToolInput(tag="in_top_only", input_type=Boolean(optional=True), prefix="--toponly", doc=InputDocumentation(doc=": only search the top strand")), ToolInput(tag="in_bottom_only", input_type=Boolean(optional=True), prefix="--bottomonly", doc=InputDocumentation(doc=": only search the bottom strand")), ToolInput(tag="in_q_format", input_type=String(optional=True), prefix="--qformat", doc=InputDocumentation(doc=": assert query <seqfile> is in format <s>: no autodetection")), ToolInput(tag="in_g_list", input_type=File(optional=True), prefix="--glist", doc=InputDocumentation(doc=": configure CMs listed in file <f> in glocal mode, others in local")), ToolInput(tag="in_clan_in", input_type=File(optional=True), prefix="--clanin", doc=InputDocumentation(doc=": read clan information from file <f>")), ToolInput(tag="in_o_clan", input_type=Boolean(optional=True), prefix="--oclan", doc=InputDocumentation(doc=": w/'--fmt 2' and '--tblout', only mark overlaps within clans")), ToolInput(tag="in_o_skip", input_type=Boolean(optional=True), prefix="--oskip", doc=InputDocumentation(doc=": w/'--fmt 2' and '--tblout', do not output lower scoring overlaps")), ToolInput(tag="in_cpu", input_type=Int(optional=True), prefix="--cpu", doc=InputDocumentation(doc=": number of parallel CPU workers to use for multithreads")), ToolInput(tag="in_options", input_type=Boolean(optional=True), prefix="-options", doc=InputDocumentation(doc="")), ToolInput(tag="in_cmdb", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_seq_file", input_type=String(), position=1, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_direct_output_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_direct_output_file", type_hint=File()), doc=OutputDocumentation(doc=": direct output to file <f>, not stdout"))], container="quay.io/biocontainers/infernal:1.1.4--h779adbc_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Cmscan_V0_1_0().translate("wdl")

